@@ -19,7 +19,11 @@ TIME_NAME="time"
 TIME_LEN = None
 TIME_LENG = None
 GROUP_NAME='forecasts'
-VAR_NAME='temp'
+VAR_NAME1='temp1'
+VAR_NAME2='temp2'
+VAR_NAME3='temp3'
+VAR_NAME4='temp4'
+VAR_NAME5='temp5'
 VAR_TYPE='f8'
 
 
@@ -28,11 +32,19 @@ class DimensionsTestCase(unittest.TestCase):
     def setUp(self):
         self.file = FILE_NAME
         f  = netCDF4.Dataset(self.file, 'w')
-        f.createDimension(LAT_NAME,LAT_LEN)
-        f.createDimension(LON_NAME,LON_LEN)
-        f.createDimension(LEVEL_NAME,LEVEL_LEN)
-        f.createDimension(TIME_NAME,TIME_LEN)
-        f.createVariable(VAR_NAME,VAR_TYPE,(LEVEL_NAME, LAT_NAME, LON_NAME, TIME_NAME))
+        lat_dim=f.createDimension(LAT_NAME,LAT_LEN)
+        lon_dim=f.createDimension(LON_NAME,LON_LEN)
+        lev_dim=f.createDimension(LEVEL_NAME,LEVEL_LEN)
+        time_dim=f.createDimension(TIME_NAME,TIME_LEN)
+        # specify dimensions with names
+        fv1 = f.createVariable(VAR_NAME1,VAR_TYPE,(LEVEL_NAME, LAT_NAME, LON_NAME, TIME_NAME))
+        # specify dimensions with instances
+        fv2 = f.createVariable(VAR_NAME2,VAR_TYPE,(lev_dim,lat_dim,lon_dim,time_dim))
+        # specify dimensions using a mix of names and instances
+        fv3 = f.createVariable(VAR_NAME3,VAR_TYPE,(lev_dim, LAT_NAME, lon_dim, TIME_NAME))
+        # single dim instance for name (not in a tuple)
+        fv4 = f.createVariable(VAR_NAME4,VAR_TYPE,time_dim)
+        fv5 = f.createVariable(VAR_NAME5,VAR_TYPE,TIME_NAME)
         g = f.createGroup(GROUP_NAME)
         g.createDimension(LAT_NAME,LAT_LENG)
         g.createDimension(LON_NAME,LON_LENG)
@@ -40,7 +52,7 @@ class DimensionsTestCase(unittest.TestCase):
         # (did not work prior to alpha 18)
         #g.createDimension(LEVEL_NAME,LEVEL_LENG)
         #g.createDimension(TIME_NAME,TIME_LENG)
-        g.createVariable(VAR_NAME,VAR_TYPE,(LEVEL_NAME, LAT_NAME, LON_NAME, TIME_NAME))
+        gv = g.createVariable(VAR_NAME1,VAR_TYPE,(LEVEL_NAME, LAT_NAME, LON_NAME, TIME_NAME))
         f.close()
 
     def tearDown(self):
@@ -51,7 +63,11 @@ class DimensionsTestCase(unittest.TestCase):
         """testing dimensions"""
         # check dimensions in root group.
         f  = netCDF4.Dataset(self.file, 'r+')
-        v = f.variables[VAR_NAME]
+        v1 = f.variables[VAR_NAME1]
+        v2 = f.variables[VAR_NAME2]
+        v3 = f.variables[VAR_NAME3]
+        v4 = f.variables[VAR_NAME4]
+        v5 = f.variables[VAR_NAME5]
         isunlim = [dim.isunlimited() for dim in f.dimensions.values()]
         dimlens = [len(dim) for dim in f.dimensions.values()]
         names_check = [LAT_NAME, LON_NAME, LEVEL_NAME, TIME_NAME]
@@ -65,6 +81,15 @@ class DimensionsTestCase(unittest.TestCase):
         # check that dimension names are correct.
         for name in f.dimensions.keys():
             self.assertTrue(name in names_check)
+        for name in v1.dimensions:
+            self.assertTrue(name in names_check)
+        for name in v2.dimensions:
+            self.assertTrue(name in names_check)
+        for name in v3.dimensions:
+            self.assertTrue(name in names_check)
+        self.assertTrue(v4.dimensions[0] == TIME_NAME)
+        self.assertTrue(v5.dimensions[0] == TIME_NAME)
+        # check that dimension lengths are correct.
         # check that dimension lengths are correct.
         for name,dim in f.dimensions.items():
             self.assertTrue(len(dim) == lensdict[name])
@@ -75,7 +100,7 @@ class DimensionsTestCase(unittest.TestCase):
         # make sure length of dimensions change correctly.
         nadd1 = 2
         nadd2 = 4
-        v[0:nadd1,:,:,0:nadd2] = uniform(size=(nadd1,LAT_LEN,LON_LEN,nadd2))
+        v1[0:nadd1,:,:,0:nadd2] = uniform(size=(nadd1,LAT_LEN,LON_LEN,nadd2))
         lensdict[LEVEL_NAME]=nadd1
         lensdict[TIME_NAME]=nadd2
         # check that dimension lengths are correct.
@@ -83,7 +108,7 @@ class DimensionsTestCase(unittest.TestCase):
             self.assertTrue(len(dim) == lensdict[name])
         # check dimensions in subgroup.
         g = f.groups[GROUP_NAME]
-        vg = g.variables[VAR_NAME]
+        vg = g.variables[VAR_NAME1]
         isunlim = [dim.isunlimited() for dim in g.dimensions.values()]
         dimlens = [len(dim) for dim in g.dimensions.values()]
         names_check = [LAT_NAME, LON_NAME, LEVEL_NAME, TIME_NAME]
